.. _fluent_pages.views:

fluent_pages.views
==================

.. automodule:: fluent_pages.views

The ``CurrentPageMixin`` class
------------------------------

.. autoclass:: fluent_pages.views.CurrentPageMixin
   :members:

The ``CurrentPageTemplateMixin`` class
--------------------------------------

.. autoclass:: fluent_pages.views.CurrentPageTemplateMixin
   :members:

The ``RobotsTxtView`` class
---------------------------

.. autoclass:: fluent_pages.views.RobotsTxtView
   :members:
